@@ -36,13 +36,13 @@ rm -f /etc/mtab >/dev/null 2>&1
 
 echo "/dev/'${DEVFS}' / reiserfs rw,usrquota,grpquota 0 0" > /etc/mtab
 mnt=`grep -v " / " /proc/mounts`
-if [ $? == 0 ]; then
+if [ $? = 0 ]; then
 	echo "$mnt" >> /etc/mtab
 fi
 chmod 644 /etc/mtab
 quotaon -aug
 ' > ${SCRIPTANAME} || {
-	echo "Unable to create ${SCRIPTNAME}"
+	echo "Unable to create ${SCRIPTANAME}"
 	exit 1
 }
 chmod 755 ${SCRIPTANAME}
