@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ static struct vps_state{
 
 const char *state2str(int state)
 {
-	int i;
+	unsigned int i;
 
 	for (i = 0; i < sizeof(vps_states) / sizeof(*vps_states); i++)
 		if (vps_states[i].id == state)
@@ -62,7 +62,7 @@ static const char *get_local_ip(vps_param *param)
 	list_head_t *h = &param->res.net.ip;
 	ip_param *ip;
 
-	/* Use first ip in the VE config */
+	/* Use first IP in the CT config */
 	if (param->g_param != NULL && !param->res.net.delall)
 		h = &param->g_param->res.net.ip;
 	if (list_empty(h))
@@ -75,7 +75,7 @@ static const char *get_local_ip(vps_param *param)
 }
 
 int vps_hostnm_configure(vps_handler *h, envid_t veid, dist_actions *actions,
-	char *root, char *hostname, const char *ip, int state)
+	const char *root, char *hostname, const char *ip, int state)
 {
 	char *envp[5];
 	const char *script;
@@ -113,7 +113,7 @@ int vps_hostnm_configure(vps_handler *h, envid_t veid, dist_actions *actions,
 }
 
 int vps_dns_configure(vps_handler *h, envid_t veid, dist_actions *actions,
-	char *root, misc_param *net, int state)
+	const char *root, misc_param *net, int state)
 {
 	char *envp[10];
 	char *str;
@@ -152,7 +152,7 @@ int vps_dns_configure(vps_handler *h, envid_t veid, dist_actions *actions,
 }
 
 int vps_pw_configure(vps_handler *h, envid_t veid, dist_actions *actions,
-	char *root, list_head_t *pw)
+	const char *root, list_head_t *pw)
 {
 	char *envp[3];
 	const char *script;
@@ -177,12 +177,12 @@ int vps_pw_configure(vps_handler *h, envid_t veid, dist_actions *actions,
 		ret = VZ_CHANGEPASS;
 		logger(0, 0, "Password change failed");
 	}
-	if (str != NULL) free(str);
+	free(str);
 	return ret;
 }
 
 int vps_quota_configure(vps_handler *h, envid_t veid, dist_actions *actions,
-	char *root, dq_param *dq, int state)
+	const char *root, dq_param *dq, int state)
 {
 	char *envp[6];
 	const char *script;
@@ -190,7 +190,6 @@ int vps_quota_configure(vps_handler *h, envid_t veid, dist_actions *actions,
 	char buf[64];
 	const char *str_state;
 	struct stat st;
-	dev_res dev;
 	const char *fs_name;
 
 	if (dq->enable == NO)
@@ -207,12 +206,6 @@ int vps_quota_configure(vps_handler *h, envid_t veid, dist_actions *actions,
 		logger(-1, errno, "Unable to stat %s", root);
 		return -1;
 	}
-	memset(&dev, 0, sizeof(dev));
-	dev.dev = st.st_dev;
-	dev.type = S_IFBLK | VE_USE_MINOR;
-	dev.mask = S_IXGRP;
-	if ((ret = set_devperm(h, veid, &dev)))
-		return ret;
 	i = 0;
 	str_state = state2str(state);
 	snprintf(buf, sizeof(buf), "VE_STATE=%s", str_state);
@@ -228,7 +221,7 @@ int vps_quota_configure(vps_handler *h, envid_t veid, dist_actions *actions,
 	}
 	envp[i++] = strdup(ENV_PATH);
 	envp[i] = NULL;
-	logger(0, 0, "Setting quota ugidlimit: %d", *dq->ugidlimit);
+	logger(0, 0, "Setting quota ugidlimit: %ld", *dq->ugidlimit);
 	ret = vps_exec_script(h, veid, root, NULL, envp, script, DIST_FUNC,
 		SCRIPT_EXEC_TIMEOUT);
 	free_arg(envp);
@@ -251,10 +244,10 @@ int need_configure(vps_res *res)
 }
 
 /*
- * Setup (add/delete) IP address(es) inside VE
+ * Setup (add/delete) IP address(es) inside container
  */
 int vps_ip_configure(vps_handler *h, envid_t veid, dist_actions *actions,
-	char *root, int op, net_param *net, int state)
+	const char *root, int op, net_param *net, int state)
 {
 	char *envp[6];
 	char *str;
@@ -302,7 +295,7 @@ int vps_ip_configure(vps_handler *h, envid_t veid, dist_actions *actions,
 	envp[i] = NULL;
 	ret = vps_exec_script(h, veid, root, NULL, envp, script, DIST_FUNC,
 		SCRIPT_EXEC_TIMEOUT);
-	if (str != NULL) free(str);
+	free(str);
 
 	return ret;
 }
@@ -310,7 +303,7 @@ int vps_ip_configure(vps_handler *h, envid_t veid, dist_actions *actions,
 
 
 int vps_configure(vps_handler *h, envid_t veid, dist_actions *actions,
-	char *root, int op, vps_param *param, int state)
+	const char *root, int op, vps_param *param, int state)
 {
 	int ret;
 	vps_res *res = &param->res;
@@ -318,7 +311,7 @@ int vps_configure(vps_handler *h, envid_t veid, dist_actions *actions,
 	if (!need_configure(res))
 		return 0;
 	if (!vps_is_run(h, veid)) {
-		logger(0, 0, "Unable to configure VE: VE is not running");
+		logger(0, 0, "Unable to configure container: not running");
 		return VZ_VE_NOT_RUNNING;
 	}
 	if (actions == NULL) {
